==> koha-16.05.03.tar.gz: koha-16.05.03/installer/data/mysql/it-IT/necessari/sample_numberpatterns.sql <==
INSERT INTO subscription_numberpatterns
    (id, label, displayorder, description, numberingmethod,
    label1, add1, every1, whenmorethan1, setto1, numbering1,
    label2, add2, every2, whenmorethan2, setto2, numbering2,
    label3, add3, every3, whenmorethan3, setto3, numbering3)
VALUES
(1,'Number',1,'Numerazione solo numerica continua','No. {X}','Number',1,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(2,'Volume, Number, Issue',2,'Volume Number Issue (rinizia ciclo: mai,12,4)','Vol. {X}, Number {Y}, Issue {Z}','Volume',1,48,99999,1,NULL,'Number',1,4,12,1,NULL,'Issue',1,1,4,1,NULL),
(3,'Volume, Number',3,'Volume Number (rinizia ciclo: mai,12)','Vol. {X}, No. {Y}','Volume',1,12,99999,1,NULL,'Number',1,1,12,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(4,'Seasonal',4,'Season Year','{X} {Y}','Season',1,1,3,0,'season','Year',1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(5,'Volume (Anno)',5,'Numero di volume e anno sempre crescenti di una unit l\'anno','{X} ({Y})','v.',1,1,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,0,0,0,0,NULL),
(6,'Annulit, Numero, Anno (10 volte all\'anno)',6,'Numero anno e numero fascicolo. Ci sono 10 fascicoli anno','a.{X} no.{Y} ({Z}) ',NULL,1,10,9999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(7,'Volume: Numero (Anno), 8 volte anno',7,'Volume, numero fascicolo e anno. Ci sono 8 fascicoli all\'anno','v.{X}:no.{Y} ({Z}) ',NULL,1,8,99999,1,NULL,NULL,1,1,8,1,NULL,NULL,1,8,99999,1,NULL),
(8,'Volume: Numero (Anno), 7 volte anno',8,'Volume, numero fascicolo e anno.  Ci sono 7 fascicoli anno','v.{X}:no.{Y} ({Z})',NULL,1,7,99999,1,NULL,NULL,1,1,7,1,NULL,NULL,1,7,99999,1,NULL),
(9,'Annulit, Numero (5 volte)',9,'Volume, numero fascicolo e anno. Ci sono 5 fascicoli anno','v.{X}:no.{Y} ({Z})',NULL,1,5,99999,1,NULL,NULL,1,1,5,1,NULL,NULL,1,5,99999,1,NULL),
(10,'Volume: Numero (Anno). 1 all\'anno',10,'Volume e anno crescenti, numero fisso. Una volta l\'anno. [a]','v.{X}:n.{Y}  ({Z})',NULL,1,3,99999,1,NULL,NULL,1,1,3,1,NULL,NULL,1,3,99999,1,NULL),
(11,'Volume: Numero (Anno). 1 ogni 2 mesi',11,'Volume e Anno crescenti, numero in ciclo. 1 ogni 2 mesi [b]','v.{X}:n.{Y}  ({Z})',NULL,1,6,99999,1,NULL,NULL,1,1,6,1,NULL,NULL,1,6,99999,1,NULL),
(12,'Volume: Numero (Anno). 1 volta a sett. con giro a 26',29,'Settimanale il cui volume cambia dopo 26 numeri [n]','v.{X}:n.{Y}  ({Z})',NULL,1,26,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,52,99999,1,NULL),
(13,'Volume: Number: Issue. 2 ogni sett.',12,'Volume crescente, numero e issue ciclici. 2 ogni sett [c]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,104,99999,1,NULL,NULL,1,2,52,1,NULL,NULL,1,1,2,1,NULL),
(14,'Volume: Numero (Anno), 1 al giorno',13,'Volume crescente, numero ciclico su 365 [d]','v.{X}:n.{Y} ({Z})',NULL,1,365,99999,1,NULL,NULL,1,1,365,1,NULL,NULL,1,365,99999,1,NULL),
(15,'Volume: Numero (Anno). 1 ogni 2 sett.',14,'Volume e Anno crescenti, numero in ciclo. 1 ogni 2 sett. [e]','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,99999,1,NULL),
(16,'Volume: Numero (Anno). 1 ogni 6 mesi',15,'Volume crescente, numero ciclico su 6 mesi [f]','v.{X}:n.{Y} ({Z})',NULL,1,2,99999,1,NULL,NULL,1,1,2,1,NULL,NULL,1,2,99999,1,NULL),
(17,'Volume (Anno). 1 ogni 2 anni',16,'Vol. e Anno aumentano di 1 ogni 2 anni [g]','v.{X} ({Y})','',1,1,99999,1,'','',2,1,9999,1,'','',0,0,0,0,''),
(18,'Volume (Anno). 1 ogni 3 anni',17,'Vol. e Anno aumentano di 1 ogni 3 anni [h]','v.{X} ({Y})',NULL,1,1,99999,1,NULL,NULL,3,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(19,'Volume: Number: Issue. 3 ogni sett.',18,'Volume crescente, numero e issue ciclici. 3 ogni sett [i]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,156,9999,1,NULL,NULL,1,3,52,1,NULL,NULL,1,1,3,1,NULL),
(20,'Volume: Number: Issue. 3 ogni mese',19,'Volume crescente, numero e issue ciclici. 3 ogni mese [j]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,36,99999,1,NULL,NULL,1,3,12,1,NULL,NULL,1,1,3,1,NULL),
(21,'Volume: Numero (Anno). 1 ogni mese',20,'Volume crescente, numero ciclico su 1 al mese [m]','v. {X}:n.{Y} ({Z})',NULL,1,6,99999,1,NULL,NULL,1,1,6,1,NULL,NULL,1,12,99999,1,NULL),
(22,'Volume: Numero (Anno). 1 ogni 3 mesi',21,'Volume crescente, numero ciclico su 3 mesi [q]','v. {X}:n.{Y} ({Z})',NULL,1,4,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,4,99999,1,NULL),
(23,'Volume: Number (Anno). 2 ogni mese',22,'Volume e Anno crescenti, numero ciclico. 2 ogni mese [s]','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,9999,1,NULL),
(24,'Volume: Numero (Anno). 1 ogni 4 mesi',23,'Volume crescente, numero ciclico su 4 mesi [t]','v. {X}:no.{Y} ({Z})',NULL,1,3,99999,1,NULL,NULL,1,1,3,1,NULL,NULL,1,3,99999,1,NULL),
(25,'Volume: Numero (Anno). 1 ogni sett.',24,'Volume e Anno crescenti, numero in ciclo. 1 ogni sett. [w]','v. {X}:n.{Y} ({Z})',NULL,1,52,99999,1,NULL,NULL,1,1,52,1,NULL,NULL,1,52,99999,1,NULL),
(26,'Number, Irregolare',25,'Irregolare [x]','n.{X}',NULL,1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(27,'Volume: Numero (Anno). 1 ogni mese, 9 per anno',28,'Volume crescente, numero ciclico su 1 al mese ma 9 per anno','v. {X}:n.{Y} ({Z})',NULL,1,9,99999,1,NULL,NULL,1,1,9,1,NULL,NULL,1,9,99999,1,NULL),
(28,'Volume: Numero (Anno). 1 ogni mese, 10 per anno',27,'Volume crescente, numero ciclico su 1 al mese ma 10 per anno','v. {X}:n.{Y} ({Z})',NULL,1,10,99999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(29,'Volume: Numero (Anno). 1 ogni mese, 11 per anno',26,'Volume crescente, numero ciclico su 1 al mese ma 11 per anno','v. {X}:n.{Y} ({Z})','',1,11,99999,1,'','',1,1,11,1,'','',1,11,99999,1,''),
(30,'Numero (Anno). 1 ogni mese',30,'','n.{Y} ({Z})',NULL,NULL,NULL,NULL,NULL,NULL,NULL,1,1,12,1,NULL,NULL,1,12,99999,1,NULL),
(31,'Annualit, Numero, Anno (4 volte all\'anno)',31,'','a.{X} no.{Y} ({Z}) ',NULL,1,4,99999,1,NULL,NULL,1,1,4,1,NULL,NULL,1,4,99999,1,NULL),
(32,'Volume (anno). 1 ogni 3 mesi',32,'','v. {X}:n.{Y} ({Z})',NULL,1,4,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,4,99999,1,NULL),
(33,'Numero (Anno). 1 ogni 6 mesi',33,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,2,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(34,'Numero (Anno). 1 ogni 3 mesi',34,'','n. {X} ({Y})',NULL,1,4,99999,1,NULL,NULL,1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(35,'Numero (Anno). 1 ogni 2 mesi',35,'','n. {X} ({Y})',NULL,1,1,6,1,NULL,NULL,1,6,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(36,'Annualit, Numero, Anno (10 volte all\'anno)',36,'','a.{X} no.{Y} ({Z}) ',NULL,1,10,9999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(37,'Volume (Anno). 1 ogni mese, 10 per anno',37,'','v. {X} {(Y)}',NULL,1,10,99999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(38,'Annualit: Numero (Anno). 1 all\'anno',38,'','a.{X}: n.{Y} ({Z})',NULL,1,1,99999,1,NULL,NULL,1,1,99999,NULL,NULL,NULL,1,1,99999,1,NULL),
(39,'Numero (Anno). 1 ogni anno',39,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(40,'Annualita: Numero (Anno). 1 ogni 6 mesi',40,'','a.{X}: n.{Y} ({Z})',NULL,1,2,99999,1,NULL,NULL,1,1,99999,NULL,NULL,NULL,1,2,99999,1,NULL),
(41,'Numero (Anno). 1 ogni mese, 10 per anno',41,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,10,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(42,'Numero (Anno). 1 ogni 4 mesi',42,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,3,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(43,'Volume (Anno). 8 volte l\'anno',43,'','v.{X} ({Y})  ',NULL,1,1,99999,1,NULL,NULL,1,8,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(44,'Annualit: Numero (Anno). 1 ogni mese',44,'','a. {X}:n.{Y} ({Z})',NULL,1,12,99999,1,NULL,NULL,1,1,12,1,NULL,NULL,1,12,99999,1,NULL),
(45,'Volume: Numero (Anno). 2 volte al mese',45,'','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,99999,1,NULL);

==> koha-20.11.13.tar.gz: koha-20.11.13/installer/data/mysql/it-IT/necessari/sample_numberpatterns.sql <==
INSERT INTO subscription_numberpatterns
    (id, label, displayorder, description, numberingmethod,
    label1, add1, every1, whenmorethan1, setto1, numbering1,
    label2, add2, every2, whenmorethan2, setto2, numbering2,
    label3, add3, every3, whenmorethan3, setto3, numbering3)
VALUES
(1,'Number',1,'Numerazione solo numerica continua','No. {X}','Number',1,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(2,'Volume, Number, Issue',2,'Volume Number Issue (rinizia ciclo: mai,12,4)','Vol. {X}, Number {Y}, Issue {Z}','Volume',1,48,99999,1,NULL,'Number',1,4,12,1,NULL,'Issue',1,1,4,1,NULL),
(3,'Volume, Number',3,'Volume Number (rinizia ciclo: mai,12)','Vol. {X}, No. {Y}','Volume',1,12,99999,1,NULL,'Number',1,1,12,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(4,'Seasonal',4,'Season Year','{X} {Y}','Season',1,1,3,0,'season','Year',1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(5,'Volume (Anno)',5,'Numero di volume e anno sempre crescenti di una unità l\'anno','{X} ({Y})','v.',1,1,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,0,0,0,0,NULL),
(6,'Annulità, Numero, Anno (10 volte all\'anno)',6,'Numero anno e numero fascicolo. Ci sono 10 fascicoli anno','a.{X} no.{Y} ({Z}) ',NULL,1,10,9999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(7,'Volume: Numero (Anno), 8 volte anno',7,'Volume, numero fascicolo e anno. Ci sono 8 fascicoli all\'anno','v.{X}:no.{Y} ({Z}) ',NULL,1,8,99999,1,NULL,NULL,1,1,8,1,NULL,NULL,1,8,99999,1,NULL),
(8,'Volume: Numero (Anno), 7 volte anno',8,'Volume, numero fascicolo e anno.  Ci sono 7 fascicoli anno','v.{X}:no.{Y} ({Z})',NULL,1,7,99999,1,NULL,NULL,1,1,7,1,NULL,NULL,1,7,99999,1,NULL),
(9,'Annulità, Numero (5 volte)',9,'Volume, numero fascicolo e anno. Ci sono 5 fascicoli anno','v.{X}:no.{Y} ({Z})',NULL,1,5,99999,1,NULL,NULL,1,1,5,1,NULL,NULL,1,5,99999,1,NULL),
(10,'Volume: Numero (Anno). 1 all\'anno',10,'Volume e anno crescenti, numero fisso. Una volta l\'anno. [a]','v.{X}:n.{Y}  ({Z})',NULL,1,3,99999,1,NULL,NULL,1,1,3,1,NULL,NULL,1,3,99999,1,NULL),
(11,'Volume: Numero (Anno). 1 ogni 2 mesi',11,'Volume e Anno crescenti, numero in ciclo. 1 ogni 2 mesi [b]','v.{X}:n.{Y}  ({Z})',NULL,1,6,99999,1,NULL,NULL,1,1,6,1,NULL,NULL,1,6,99999,1,NULL),
(12,'Volume: Numero (Anno). 1 volta a sett. con giro a 26',29,'Settimanale il cui volume cambia dopo 26 numeri [n]','v.{X}:n.{Y}  ({Z})',NULL,1,26,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,52,99999,1,NULL),
(13,'Volume: Number: Issue. 2 ogni sett.',12,'Volume crescente, numero e issue ciclici. 2 ogni sett [c]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,104,99999,1,NULL,NULL,1,2,52,1,NULL,NULL,1,1,2,1,NULL),
(14,'Volume: Numero (Anno), 1 al giorno',13,'Volume crescente, numero ciclico su 365 [d]','v.{X}:n.{Y} ({Z})',NULL,1,365,99999,1,NULL,NULL,1,1,365,1,NULL,NULL,1,365,99999,1,NULL),
(15,'Volume: Numero (Anno). 1 ogni 2 sett.',14,'Volume e Anno crescenti, numero in ciclo. 1 ogni 2 sett. [e]','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,99999,1,NULL),
(16,'Volume: Numero (Anno). 1 ogni 6 mesi',15,'Volume crescente, numero ciclico su 6 mesi [f]','v.{X}:n.{Y} ({Z})',NULL,1,2,99999,1,NULL,NULL,1,1,2,1,NULL,NULL,1,2,99999,1,NULL),
(17,'Volume (Anno). 1 ogni 2 anni',16,'Vol. e Anno aumentano di 1 ogni 2 anni [g]','v.{X} ({Y})','',1,1,99999,1,'','',2,1,9999,1,'','',0,0,0,0,''),
(18,'Volume (Anno). 1 ogni 3 anni',17,'Vol. e Anno aumentano di 1 ogni 3 anni [h]','v.{X} ({Y})',NULL,1,1,99999,1,NULL,NULL,3,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(19,'Volume: Number: Issue. 3 ogni sett.',18,'Volume crescente, numero e issue ciclici. 3 ogni sett [i]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,156,9999,1,NULL,NULL,1,3,52,1,NULL,NULL,1,1,3,1,NULL),
(20,'Volume: Number: Issue. 3 ogni mese',19,'Volume crescente, numero e issue ciclici. 3 ogni mese [j]','v.{X}:n.{Y}:fasc.{Z}',NULL,1,36,99999,1,NULL,NULL,1,3,12,1,NULL,NULL,1,1,3,1,NULL),
(21,'Volume: Numero (Anno). 1 ogni mese',20,'Volume crescente, numero ciclico su 1 al mese [m]','v. {X}:n.{Y} ({Z})',NULL,1,6,99999,1,NULL,NULL,1,1,6,1,NULL,NULL,1,12,99999,1,NULL),
(22,'Volume: Numero (Anno). 1 ogni 3 mesi',21,'Volume crescente, numero ciclico su 3 mesi [q]','v. {X}:n.{Y} ({Z})',NULL,1,4,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,4,99999,1,NULL),
(23,'Volume: Number (Anno). 2 ogni mese',22,'Volume e Anno crescenti, numero ciclico. 2 ogni mese [s]','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,9999,1,NULL),
(24,'Volume: Numero (Anno). 1 ogni 4 mesi',23,'Volume crescente, numero ciclico su 4 mesi [t]','v. {X}:no.{Y} ({Z})',NULL,1,3,99999,1,NULL,NULL,1,1,3,1,NULL,NULL,1,3,99999,1,NULL),
(25,'Volume: Numero (Anno). 1 ogni sett.',24,'Volume e Anno crescenti, numero in ciclo. 1 ogni sett. [w]','v. {X}:n.{Y} ({Z})',NULL,1,52,99999,1,NULL,NULL,1,1,52,1,NULL,NULL,1,52,99999,1,NULL),
(26,'Number, Irregolare',25,'Irregolare [x]','n.{X}',NULL,1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(27,'Volume: Numero (Anno). 1 ogni mese, 9 per anno',28,'Volume crescente, numero ciclico su 1 al mese ma 9 per anno','v. {X}:n.{Y} ({Z})',NULL,1,9,99999,1,NULL,NULL,1,1,9,1,NULL,NULL,1,9,99999,1,NULL),
(28,'Volume: Numero (Anno). 1 ogni mese, 10 per anno',27,'Volume crescente, numero ciclico su 1 al mese ma 10 per anno','v. {X}:n.{Y} ({Z})',NULL,1,10,99999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(29,'Volume: Numero (Anno). 1 ogni mese, 11 per anno',26,'Volume crescente, numero ciclico su 1 al mese ma 11 per anno','v. {X}:n.{Y} ({Z})','',1,11,99999,1,'','',1,1,11,1,'','',1,11,99999,1,''),
(30,'Numero (Anno). 1 ogni mese',30,'','n.{Y} ({Z})',NULL,NULL,NULL,NULL,NULL,NULL,NULL,1,1,12,1,NULL,NULL,1,12,99999,1,NULL),
(31,'Annualità, Numero, Anno (4 volte all\'anno)',31,'','a.{X} no.{Y} ({Z}) ',NULL,1,4,99999,1,NULL,NULL,1,1,4,1,NULL,NULL,1,4,99999,1,NULL),
(32,'Volume (anno). 1 ogni 3 mesi',32,'','v. {X}:n.{Y} ({Z})',NULL,1,4,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,1,4,99999,1,NULL),
(33,'Numero (Anno). 1 ogni 6 mesi',33,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,2,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(34,'Numero (Anno). 1 ogni 3 mesi',34,'','n. {X} ({Y})',NULL,1,4,99999,1,NULL,NULL,1,4,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(35,'Numero (Anno). 1 ogni 2 mesi',35,'','n. {X} ({Y})',NULL,1,1,6,1,NULL,NULL,1,6,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(36,'Annualità, Numero, Anno (10 volte all\'anno)',36,'','a.{X} no.{Y} ({Z}) ',NULL,1,10,9999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(37,'Volume (Anno). 1 ogni mese, 10 per anno',37,'','v. {X} {(Y)}',NULL,1,10,99999,1,NULL,NULL,1,1,10,1,NULL,NULL,1,10,99999,1,NULL),
(38,'Annualità: Numero (Anno). 1 all\'anno',38,'','a.{X}: n.{Y} ({Z})',NULL,1,1,99999,1,NULL,NULL,1,1,99999,NULL,NULL,NULL,1,1,99999,1,NULL),
(39,'Numero (Anno). 1 ogni anno',39,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,1,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(40,'Annualita: Numero (Anno). 1 ogni 6 mesi',40,'','a.{X}: n.{Y} ({Z})',NULL,1,2,99999,1,NULL,NULL,1,1,99999,NULL,NULL,NULL,1,2,99999,1,NULL),
(41,'Numero (Anno). 1 ogni mese, 10 per anno',41,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,10,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(42,'Numero (Anno). 1 ogni 4 mesi',42,'','n. {X} ({Y})',NULL,1,1,99999,1,NULL,NULL,1,3,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(43,'Volume (Anno). 8 volte l\'anno',43,'','v.{X} ({Y})  ',NULL,1,1,99999,1,NULL,NULL,1,8,99999,1,NULL,NULL,NULL,NULL,NULL,NULL,NULL),
(44,'Annualità: Numero (Anno). 1 ogni mese',44,'','a. {X}:n.{Y} ({Z})',NULL,1,12,99999,1,NULL,NULL,1,1,12,1,NULL,NULL,1,12,99999,1,NULL),
(45,'Volume: Numero (Anno). 2 volte al mese',45,'','v.{X}:n.{Y} ({Z})',NULL,1,24,99999,1,NULL,NULL,1,1,24,1,NULL,NULL,1,24,99999,1,NULL);
